<?php
App::uses('AppHelper', 'View/Helper');

class ProductsHelper extends AppHelper {

	/**
	 * for a product with single variant, extract the requests data
	 *
	 * @param 	string 		The column to extract
	 * @param 	array 		The Data array
	 * @return 	mixed 		The extracted data or bool false if multiple variants
	 */
	public function singleVariantData($item, $data) {
		if (count($data['Variant']) > 1) {
			return false;
		}

		return Hash::get($data, 'Variant.0.' . $item);
	}

	/**
	 * get the option groups for the variants
	 *
	 * @param  	array 	Product Data array
	 * @return 	array 	Array of option groups
	 */
	public function getOptionGroups($data) {
		if (! empty($data['Variant']['0']['Option'])) {
			return Hash::combine($data['Variant'], '{n}.Option.{n}.OptionGroup.id', '{n}.Option.{n}.OptionGroup.name');
		}

		return array();
	}

	/**
	 * given the variant array and the option group
	 * return the option name
	 *
	 * @param 	array 	Variant Array
	 * @param 	int 	Option group Id
	 * @return 	string 	Option value
	 */
	public function getOption($Variant, $groupId) {
		return Hash::get($Variant, 'Option.' . $groupId . '.name', '-');
	}

	public function getGenericVariantImages($allVariantImages) {
		foreach ($allVariantImages as $imageKey => $image) {
			if (isset($image['is_restricted']) && $image['is_restricted']) {
				unset($allVariantImages[$imageKey]);
			}
		}

		return $allVariantImages;
	}

	public function getRestrictedVariantImages($allVariantImages) {
		foreach ($allVariantImages as $imageKey => $image) {
			if (!isset($image['is_restricted']) || !$image['is_restricted']) {
				unset($allVariantImages[$imageKey]);
			}

			if (!isset($image['VariantImageOption']) || empty($image['VariantImageOption'])) {
				unset($allVariantImages[$imageKey]);
			}
		}

		return $allVariantImages;
	}

	public function getRestrictedImagesForVariant($variant, $variantImages) {
		$imageArray = [];

		if (isset($variant['Option']) && !empty($variant['Option'])) {
			$allVariantOptions = Hash::extract($variant['Option'], '{n}.id');

			$restrictedImages = $this->getRestrictedVariantImages($variantImages);

			foreach ($restrictedImages as $image) {
				$currentGroupsChecked = [];

				foreach ($image['VariantImageOption'] as $imageOption) {
					if (!isset($currentGroupsChecked[$imageOption['option_group_id']])) {
						$currentGroupsChecked[$imageOption['option_group_id']] = false;
					}

					if (in_array($imageOption['option_id'], $allVariantOptions)) {
						$currentGroupsChecked[$imageOption['option_group_id']] = true;
					}
				}

				if (!in_array(false, $currentGroupsChecked)) {
					$imageArray[] = $image;
				}
			}
		}

		return $imageArray;
	}
}
